@@ -1,5 +1,5 @@
 /*
- * Copyright  1993-1998 Marc Baudoin <babafou@agm-ita.ensta.fr>
+ * Copyright  1993-1999 Marc Baudoin <babafou@babafou.eu.org>
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -12,7 +12,7 @@
  *
  */
 
-static char *const cvsid = "$Id: main.c,v 1.3 1998/02/09 11:15:51 babafou Exp $" ;
+static char *const cvsid = "$Id: main.c,v 1.3.2.2 1999/08/01 20:57:46 babafou Exp $" ;
 
 #include <sys/types.h>
 
@@ -49,9 +49,9 @@ int main ( int argc , char **argv )
       if ( strcmp ( argv[i] , "-v" ) == 0 )
       {
          unsigned char *message = "\
-xdmineur 2.1\n\
+xdmineur 2.1.1\n\
 \n\
-Copyright  1993-1998 Marc Baudoin <babafou@agm-ita.ensta.fr>\n\
+Copyright  1993-1999 Marc Baudoin <babafou@babafou.eu.org>\n\
 \n\
 Permission to use, copy, modify, and distribute this software and\n\
 its documentation for any purpose and without fee is hereby\n\
