@@ -1,5 +1,5 @@
 /*
- * Copyright  1993-1998 Marc Baudoin <babafou@agm-ita.ensta.fr>
+ * Copyright  1993-1999 Marc Baudoin <babafou@babafou.eu.org>
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -12,7 +12,7 @@
  *
  */
 
-static char *const cvsid = "$Id: xdemineur.c,v 1.3 1998/02/09 11:15:54 babafou Exp $" ;
+static char *const cvsid = "$Id: xdemineur.c,v 1.3.2.2 1999/07/29 21:25:33 babafou Exp $" ;
 
 #include <sys/types.h>
 
@@ -273,10 +273,11 @@ void xdemineur_initialize ( int argc , char **argv ,
                                          xdemineur_bits ,
                                          xdemineur_width , xdemineur_height ) ;
 
-   wm_hints.flags         = InputHint | StateHint | IconPixmapHint ;
+   wm_hints.flags         = InputHint | StateHint | IconPixmapHint | WindowGroupHint;
    wm_hints.input         = True ;
    wm_hints.initial_state = NormalState ;
    wm_hints.icon_pixmap   = icon_bitmap ;
+   wm_hints.window_group  = window ;
 
    class_hints.res_name  = argv[0] ;
    class_hints.res_class = "XDmineur" ;
@@ -286,6 +287,8 @@ void xdemineur_initialize ( int argc , char **argv ,
                       argv , argc ,
                       &size_hints , &wm_hints , &class_hints ) ;
 
+   XSetCommand ( display , window , argv , argc ) ;
+
    protocol[0] = XInternAtom ( display , "WM_DELETE_WINDOW" , False ) ;
    XSetWMProtocols ( display , window , protocol , 1 ) ;
 
